@@ -31,12 +31,12 @@ void test06(void)
   // seekg
   {
     wistringstream iss(num1);
-    iss.tellg();
+    wistream::pos_type pos1 = iss.tellg();
     int asNum = 0;
     iss >> asNum;
     VERIFY( iss.eof() );
     VERIFY( !iss.fail() );
-    iss.seekg(0, ios_base::beg);
+    iss.seekg(pos1);
     VERIFY( !iss.fail() );
   }
 }
