@@ -1,6 +1,6 @@
 // 2003-02-26 Benjamin Kosnik <bkoz@redhat.com>
 
-// Copyright (C) 2003-2024 Free Software Foundation, Inc.
+// Copyright (C) 2003-2025 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -26,9 +26,14 @@ int main()
 {
   using namespace __gnu_test;
 
-  // Equivalent, but formatting difference in void argument.
-  //  verify_demangle("_Z1fM1AFivEPS0_", "f(int (A::*)(void), int (*)(void))");
-  verify_demangle("_Z1fM1AFivEPS0_", "f(int (A::*)(), int (*)())");
+ // cplus-dem FAIL
+  // Equivalent as considered order-insensitive?
+  // standard text, icc FAIL
+  //  verify_demangle("_ZlsRKU3fooU4bart1XS0_", 
+  //     "operator<<(X const foo bart&, X const foo bart)");
+  // new __cxa_demangle
+  verify_demangle("_ZlsRKU3fooU4bart1XS0_", 
+		  "operator<<(X bart foo const&, X bart)");
 
   return 0;
 }
